@@ -19,7 +19,8 @@
  ***************************************************************************/
 #include "movedatafilesjob.h"
 #include <QFileInfo>
-#include <KLocale>
+#include <QUrl>
+#include <klocalizedstring.h>
 #include <kjobtrackerinterface.h>
 #include <kio/jobuidelegate.h>
 #include <util/log.h>
@@ -165,12 +166,12 @@ namespace bt
 		}
 			
 		QMap<QString,QString>::iterator i = todo.begin();
-		active_job = KIO::file_move(KUrl(i.key()),KUrl(i.value()),-1,KIO::HideProgressInfo);
+		active_job = KIO::file_move(QUrl::fromLocalFile(i.key()),QUrl::fromLocalFile(i.value()),-1,KIO::HideProgressInfo);
 		active_src = i.key();
 		active_dst = i.value();
 		Out(SYS_GEN|LOG_DEBUG) << "Moving " << active_src << " -> " << active_dst << endl;
-		connect(active_job,SIGNAL(result(KJob*)),this,SLOT(onJobDone(KJob*)));
-		connect(active_job,SIGNAL(canceled(KJob*)),this,SLOT(onCanceled(KJob*)));
+		connect(active_job, &KIO::Job::result, this, &MoveDataFilesJob::onJobDone);
+		connect(active_job, &KIO::Job::canceled, this, &MoveDataFilesJob::onCanceled);
 		connect(active_job,SIGNAL(processedAmount(KJob*,KJob::Unit,qulonglong)),
 				this,SLOT(onTransferred(KJob*,KJob::Unit,qulonglong)));
 		connect(active_job,SIGNAL(speed(KJob*,ulong)),
@@ -198,8 +199,8 @@ namespace bt
 		QMap<QString,QString>::iterator i = success.begin();
 		while (i != success.end())
 		{	
-			KIO::Job* j = KIO::file_move(KUrl(i.value()),KUrl(i.key()),-1,KIO::HideProgressInfo);
-			connect(j,SIGNAL(result(KJob*)),this,SLOT(onRecoveryJobDone(KJob*)));
+			KIO::Job* j = KIO::file_move(QUrl::fromLocalFile(i.value()),QUrl::fromLocalFile(i.key()),-1,KIO::HideProgressInfo);
+			connect(j, &KIO::Job::result, this, &MoveDataFilesJob::onRecoveryJobDone);
 			running_recovery_jobs++;
 			i++;
 		}
@@ -232,4 +233,3 @@ namespace bt
 
 
 }
-#include "movedatafilesjob.moc"
