@@ -22,9 +22,9 @@
 #include <unistd.h>
 #include <util/functions.h>
 #include <util/log.h>
-#include <mse/streamsocket.h>
+#include <mse/encryptedpacketsocket.h>
 #include "authenticatebase.h"
-#include <kdebug.h>
+#include "peerconnector.h"
 
 
 namespace bt
@@ -51,6 +51,14 @@ namespace bt
 		}
 		auths.clear();
 	}
+	
+	void AuthenticationMonitor::shutdown()
+	{
+		// No more active PeerConnector's allowed
+		PeerConnector::setMaxActive(0);
+		clear();
+	}
+
 
 
 	void AuthenticationMonitor::add(AuthenticateBase* s)
@@ -83,7 +91,7 @@ namespace bt
 			}
 			else
 			{
-				mse::StreamSocket* socket = ab->getSocket();
+				mse::EncryptedPacketSocket::Ptr socket = ab->getSocket();
 				if (socket)
 				{
 					net::SocketDevice* dev = socket->socketDevice();
@@ -117,7 +125,7 @@ namespace bt
 			}
 			else
 			{
-				mse::StreamSocket* socket = ab->getSocket();
+				mse::EncryptedPacketSocket::Ptr socket = ab->getSocket();
 				if (socket)
 				{
 					net::SocketDevice* dev = socket->socketDevice();
