@@ -72,7 +72,7 @@ namespace bt
 
 	PeerDownloader::PeerDownloader(Peer* peer,Uint32 chunk_size) : peer(peer),chunk_size(chunk_size / MAX_PIECE_LEN)
 	{
-		connect(peer,SIGNAL(destroyed()),this,SLOT(peerDestroyed()));
+		connect(peer, &Peer::destroyed, this, &PeerDownloader::peerDestroyed);
 		max_wait_queue_size = 25;
 	}
 
@@ -246,7 +246,7 @@ namespace bt
 		double pieces_per_sec = (double)peer->getDownloadRate() / MAX_PIECE_LEN;	
 		int max_reqs = 1 + (int)ceil(10*pieces_per_sec);
 		// cap if client has supplied a reqq in extended protocol handshake
-		if (max_reqs > peer->getStats().max_request_queue && peer->getStats().max_request_queue != 0)
+		if (max_reqs > (int)peer->getStats().max_request_queue && peer->getStats().max_request_queue != 0)
 			max_reqs = peer->getStats().max_request_queue;
 		
 		while (wait_queue.count() > 0 && reqs.count() < max_reqs)
