@@ -25,7 +25,7 @@
 #include <utp/utpsocket.h>
 #include <utp/utpserver.h>
 #include <util/functions.h>
-#include <time.h>
+#include <ctime>
 #include <unistd.h>
 
 
