@@ -35,18 +35,29 @@ public:
 	{
 	}
 	
-	virtual bool sendTo(const QByteArray & data,const net::Address & addr,quint16 conn_id)
+	virtual bool sendTo(Connection::Ptr conn, const PacketBuffer & packet)
 	{
-		sent_packets.append(data);
-		Q_UNUSED(addr);
-		Q_UNUSED(conn_id);
+		sent_packets.append(packet);
+		Q_UNUSED(conn);
 		return true;
 	}
 	
-	QByteArray buildPacket(bt::Uint32 type,bt::Uint32 recv_conn_id,bt::Uint32 send_conn_id,bt::Uint16 seq_nr,bt::Uint16 ack_nr)
+    virtual void stateChanged(Connection::Ptr conn, bool readable, bool writeable)
+	{
+		Q_UNUSED(conn);
+		Q_UNUSED(readable);
+		Q_UNUSED(writeable);
+	}
+	
+    virtual void closed(Connection::Ptr conn)
+	{
+		Q_UNUSED(conn);
+	}
+	
+	bt::Buffer::Ptr buildPacket(bt::Uint32 type,bt::Uint32 recv_conn_id,bt::Uint32 send_conn_id,bt::Uint16 seq_nr,bt::Uint16 ack_nr)
 	{
 		TimeValue tv;
-		QByteArray ba(Header::size(),0);
+		bt::Buffer::Ptr packet = pool->get(Header::size());
 		Header hdr;
 		hdr.version = 1;
 		hdr.type = type;
@@ -57,8 +68,8 @@ public:
 		hdr.wnd_size = 6666;
 		hdr.seq_nr = seq_nr;
 		hdr.ack_nr = ack_nr;
-		hdr.write((bt::Uint8*)ba.data());
-		return ba;
+		hdr.write(packet->get());
+		return packet;
 	}
 	
 public slots:
@@ -68,10 +79,13 @@ private slots:
 	void initTestCase()
 	{
 		bt::InitLog("connectiontest.log");
+		pool = bt::BufferPool::Ptr(new bt::BufferPool());
+		pool->setWeakPointer(pool.toWeakRef());
 	}
 	
 	void cleanupTestCase()
 	{
+		pool.clear();
 	}
 	
 	void init()
@@ -100,8 +114,8 @@ private slots:
 		QVERIFY(s.state == utp::CS_SYN_SENT);
 		QVERIFY(s.seq_nr == 2);
 		
-		QByteArray pkt = buildPacket(ST_STATE,conn_id,conn_id + 1,1,1);
-		PacketParser pp(pkt);
+		bt::Buffer::Ptr pkt = buildPacket(ST_STATE,conn_id,conn_id + 1,1,1);
+		PacketParser pp(pkt->get(), pkt->size());
 		QVERIFY(pp.parse());
 		conn.handlePacket(pp,pkt);
 		QVERIFY(s.state == CS_CONNECTED);
@@ -114,8 +128,8 @@ private slots:
 		Connection conn(conn_id,utp::Connection::INCOMING,remote,this);
 		const Connection::Stats & s = conn.connectionStats();
 		
-		QByteArray pkt = buildPacket(ST_SYN,conn_id - 1,conn_id,1,1);
-		PacketParser pp(pkt);
+		bt::Buffer::Ptr pkt = buildPacket(ST_SYN,conn_id - 1,conn_id,1,1);
+		PacketParser pp(pkt->get(), pkt->size());
 		conn.handlePacket(pp,pkt);
 		QVERIFY(s.state == CS_CONNECTED);
 	}
@@ -123,9 +137,11 @@ private slots:
 	
 private:
 	net::Address remote;
-	QList<QByteArray> sent_packets;
+	QList<PacketBuffer> sent_packets;
+	bt::BufferPool::Ptr pool;
 };
 
 QTEST_MAIN(ConnectionTest)
 
-#include "connectiontest.moc"
\ No newline at end of file
+#include "connectiontest.moc"
+
